GrammarException class final

Thrown when a grammar is invalid: a bad pattern, an unknown include or an include cycle.

Implemented types

Constructors

GrammarException(String grammar, String message)
Creates a grammar exception.
const

Properties

grammar → String
Name of the grammar that failed.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
What went wrong.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited