rawEnds property
Int32List
get
rawEnds
The raw token end offsets, for engines that copy tokens in bulk. Only the first tokenCount entries are valid.
Implementation
Int32List get rawEnds => _ends;
The raw token end offsets, for engines that copy tokens in bulk. Only the first tokenCount entries are valid.
Int32List get rawEnds => _ends;